diff Core/Toolbox.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 166664f0f860
children c996319e90bc
line wrap: on
line diff
--- a/Core/Toolbox.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/Toolbox.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "Toolbox.h"
 
-#include "PalantirException.h"
+#include "PalanthirException.h"
 
 #include <string.h>
 #include <boost/filesystem.hpp>
@@ -39,7 +39,7 @@
 #include "../Resources/md5/md5.h"
 #include "../Resources/base64/base64.h"
 
-namespace Palantir
+namespace Palanthir
 {
   static bool finish;
 
@@ -125,7 +125,7 @@
     f.open(path, std::ifstream::in | std::ios::binary);
     if (!f.good())
     {
-      throw PalantirException("Unable to open a file");
+      throw PalanthirException("Unable to open a file");
     }
 
     // http://www.cplusplus.com/reference/iostream/istream/tellg/
@@ -150,7 +150,7 @@
       if (boost::filesystem::is_regular_file(path))
         boost::filesystem::remove(path);
       else
-        throw PalantirException("The path is not a regular file: " + path);
+        throw PalanthirException("The path is not a regular file: " + path);
     }
   }
 
@@ -166,7 +166,7 @@
     if (uri.size() == 0 ||
         uri[0] != URI_SEPARATOR)
     {
-      throw PalantirException(ErrorCode_UriSyntax);
+      throw PalanthirException(ErrorCode_UriSyntax);
     }
 
     // Count the number of slashes in the URI to make an assumption
@@ -301,7 +301,7 @@
     }
     catch (boost::filesystem::filesystem_error)
     {
-      throw PalantirException(ErrorCode_InexistentFile);
+      throw PalanthirException(ErrorCode_InexistentFile);
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium